Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(381)

Unified Diff: src/x64/builtins-x64.cc

Issue 6992072: Implement set trap for proxies, and revamp class hierarchy in preparation (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/x64/builtins-x64.cc
diff --git a/src/x64/builtins-x64.cc b/src/x64/builtins-x64.cc
index 57cde6520612c2cae306dc7b20ef7af63daf5ef7..06e874fc46a059133012f2680ac99d3e70ccbb89 100644
--- a/src/x64/builtins-x64.cc
+++ b/src/x64/builtins-x64.cc
@@ -360,8 +360,9 @@ static void Generate_JSConstructStubHelper(MacroAssembler* masm,
__ JumpIfSmi(rax, &use_receiver);
// If the type of the result (stored in its map) is less than
- // FIRST_JS_OBJECT_TYPE, it is not an object in the ECMA sense.
- __ CmpObjectType(rax, FIRST_JS_OBJECT_TYPE, rcx);
+ // FIRST_OBJECT_OR_FUNCTION_CLASS_TYPE, it is not an object in the ECMA sense.
+ STATIC_ASSERT(LAST_OBJECT_OR_FUNCTION_CLASS_TYPE == LAST_TYPE);
+ __ CmpObjectType(rax, FIRST_OBJECT_OR_FUNCTION_CLASS_TYPE, rcx);
__ j(above_equal, &exit);
// Throw away the result of the constructor invocation and use the
« src/arm/lithium-codegen-arm.cc ('K') | « src/runtime.cc ('k') | src/x64/code-stubs-x64.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698